@@ -2,13 +2,15 @@
 # Copyright (c) 2022 Airbyte, Inc., all rights reserved.
 #
 
-from abc import ABC, abstractmethod
+from abc import abstractmethod
 from dataclasses import dataclass
 from typing import Any, Mapping
 
+from dataclasses_jsonschema import JsonSchemaMixin
+
 
 @dataclass
-class SchemaLoader(ABC):
+class SchemaLoader(JsonSchemaMixin):
     """Describes a stream's schema"""
 
     @abstractmethod
